@@ -4,7 +4,7 @@ from pie_extended.pipeline.postprocessor.proto import ProcessorPrototype
 from pie_extended.pipeline.postprocessor.memory import MemoryzingProcessor
 
 
-def get_iterator_and_processor():
+def get_iterator_and_processor(max_tokens=256):
     tokenizer = FrMemorizingTokenizer()
     processor = MemoryzingProcessor(
         tokenizer_memory=tokenizer,
@@ -12,7 +12,8 @@ def get_iterator_and_processor():
     )
 
     iterator = DataIterator(
-        tokenizer=tokenizer
+        tokenizer=tokenizer,
+        max_tokens=max_tokens
     )
     return iterator, processor
 
