@@ -5,7 +5,7 @@ from pie_extended.pipeline.iterators.proto import DataIterator, GenericExcludePa
 from pie_extended.pipeline.postprocessor.memory import MemoryzingProcessor
 
 
-def get_iterator_and_processor():
+def get_iterator_and_processor(max_tokens=256):
     tokenizer = FroMemorizingTokenizer()
     processor = FroRulesProcessor(
         apply_on_reinsert=True,
@@ -18,7 +18,8 @@ def get_iterator_and_processor():
     )
     iterator = DataIterator(
         tokenizer=tokenizer,
-        exclude_patterns=[GenericExcludePatterns.Punctuation_and_Underscore]
+        exclude_patterns=[GenericExcludePatterns.Punctuation_and_Underscore],
+        max_tokens=max_tokens
     )
     return iterator, processor
 
