@@ -9,7 +9,7 @@ DESC = Metadata(
     "https://github.com/chartes/deucalion-model-lasla"
 )
 
-VERSION = "0.0.2"
+VERSION = "0.0.5alpha"
 DOWNLOADS = [
     File("https://raw.githubusercontent.com/PonteIneptique/latin-lasla-models/"+VERSION+"/latin-straight.json",
          "latin-straight.json"),
@@ -17,8 +17,8 @@ DOWNLOADS = [
          "latin-pos.json"),
     File("https://raw.githubusercontent.com/PonteIneptique/latin-lasla-models/"+VERSION+"/latin-needs.json",
          "latin-needs.json"),
-    File("https://raw.githubusercontent.com/PonteIneptique/latin-lasla-models/"+VERSION+"/model.tar",
+    File("https://github.com/PonteIneptique/latin-lasla-models/releases/download/"+VERSION+"/model-lasla-plus.tar",
          "model.tar")
 ]
 
-Models = "<{},lemma,Deg,Numb,Person,Mood_Tense_Voice,Case,Gend,pos>".format(get_path("lasla", "model.tar"))
+Models = "<{},lemma,Deg,Numb,Person,Mood_Tense_Voice,Case,Gend,Dis,pos>".format(get_path("lasla", "model.tar"))
