@@ -2,7 +2,7 @@ import regex as re
 from ...utils import get_path, ObjectCreator
 
 from autocat import NeedsDisambiguation, StraightAutodisambiguation, CategoryAutodisambiguation, GroupAutodisambiguation
-from ...pipeline.disambiguators.autocat import Autocat
+from ...pipeline.disambiguators.autocat import Autocat, DisambiguationAsTask
 from pie_extended.models.lasla.processor import LatinRulesProcessor, LatinGlueProcessor, MoodTenseVoice
 from pie_extended.pipeline.postprocessor.proto import ProcessorPrototype
 from pie_extended.models.lasla.tokenizer import LatMemorizingTokenizer
@@ -14,7 +14,7 @@ from pie_extended.pipeline.postprocessor.splitter import SplitterPostProcessor
 uppercase = re.compile(r"^[A-Z]$")
 
 
-def get_iterator_and_processor():
+def get_iterator_and_processor(max_tokens=256):
     tokenizer = LatMemorizingTokenizer()
     processor = LatinRulesProcessor(
         apply_on_reinsert=True,
@@ -33,7 +33,14 @@ def get_iterator_and_processor():
     )
     iterator = DataIterator(
         tokenizer=tokenizer,
-        exclude_patterns=[GenericExcludePatterns.Punctuation_and_Underscore]
+        exclude_patterns=[
+                             excl.exclude_regexp
+                             for excl in tokenizer.normalizers
+                             if excl.exclude_regexp
+                         ] + [
+                            GenericExcludePatterns.Punctuation_and_Underscore
+                         ],
+        max_tokens=max_tokens
     )
     return iterator, processor
 
@@ -45,7 +52,9 @@ def _get_disambiguator():
         get_path("lasla", "latin-straight.json"), lemma_key="lemma")
     impossible = NeedsDisambiguation.from_file(
         get_path("lasla", "latin-needs.json"), lemma_key="lemma")
-    return Autocat(GroupAutodisambiguation(lemma_key="lemma", categorizers=(straight, pos, impossible)))
+    tasks = DisambiguationAsTask(task_name="Dis", separator="", undisambiguated_marker="?",
+                                 lemma_key="lemma", empty_value="_", impossible_disambiguator=impossible)
+    return Autocat(GroupAutodisambiguation(lemma_key="lemma", categorizers=(straight, pos, tasks)))
 
 
 Disambiguator: ObjectCreator = ObjectCreator(_get_disambiguator)
