@@ -1,25 +1,36 @@
 import regex as re
-from typing import List, Generator
+from typing import List, Generator, Tuple
+from unidecode import unidecode
 
-from pie_extended.models.fro.tokenizer import _Dots_except_apostrophe, _RomanNumber
+from pie_extended.models.fro.tokenizer import _Dots_except_apostrophe
 from pie_extended.pipeline.tokenizers.memorizing import MemorizingTokenizer
 from pie_extended.models.lasla._params import abbrs
+from pie_extended.pipeline.tokenizers.utils.excluder import (
+    ReferenceExcluder,
+    ExcluderPrototype,
+    RegexpExcluder,
+    AbbreviationsRemoverExcluder
+)
+from pie_extended.pipeline.tokenizers.utils import regexps
 from pie_extended.utils import roman_number
 
+
 class LatMemorizingTokenizer(MemorizingTokenizer):
     re_add_space_around_punct = re.compile(r"(\s*)([^\w\s])(\s*)")
-    re_abbr_dot = re.compile(
-        r"("+r"|".join([abbr.replace(".", "") for abbr in abbrs])+r")(\.)"
-    )
+    re_words = re.compile("^\w+$")
     _sentence_boundaries = re.compile(
         r"([" + _Dots_except_apostrophe + r"]+\s*)+"
     )
-    roman_number_dot = re.compile(r"\.(" + _RomanNumber + r")\.")
-    re_roman_number = re.compile(r"^"+_RomanNumber+"$")
+    re_roman_number = re.compile(r"^"+regexps.RomanNumbers+"$")
 
     def __init__(self):
         super(LatMemorizingTokenizer, self).__init__()
         self.tokens = []
+        self.normalizers: Tuple[ExcluderPrototype, ...] = (
+            ReferenceExcluder(),
+            RegexpExcluder(r"(\p{No})"),
+            AbbreviationsRemoverExcluder(abbrs=abbrs)
+        )
 
     @staticmethod
     def _sentence_tokenizer_merge_matches(match):
@@ -27,10 +38,12 @@ class LatMemorizingTokenizer(MemorizingTokenizer):
         start, end = match.span()
         return match.string[start:end] + "<SPLIT>"
 
-    @classmethod
-    def _real_sentence_tokenizer(cls, string: str) -> List[str]:
-        string = cls._sentence_boundaries.sub(cls._sentence_tokenizer_merge_matches, string)
-        string = string.replace("語", ".")
+    def _real_sentence_tokenizer(self, string: str) -> List[str]:
+        string = self._sentence_boundaries.sub(self._sentence_tokenizer_merge_matches, string)
+
+        for normalizer in self.normalizers:
+            string = normalizer.after_sentence_tokenizer(string)
+
         return string.split("<SPLIT>")
 
     def _real_word_tokenizer(self, text: str, lower: bool = False) -> List[str]:
@@ -54,17 +67,12 @@ class LatMemorizingTokenizer(MemorizingTokenizer):
                 sentences.append(self.word_tokenizer(sent))
         yield from sentences
 
-    def _abbr_replace(self, match):
-        string, dot = (match.groups())
-        return string+'語'
-
     def normalizer(self, data: str) -> str:
+        for excluder in self.normalizers:
+            data = excluder.before_sentence_tokenizer(data)
         data = self.re_add_space_around_punct.sub(
             r" \g<2> ",
-            self.re_abbr_dot.sub(
-                self._abbr_replace,
-                data
-            )
+            data
         )
         return data
 
@@ -75,13 +83,28 @@ class LatMemorizingTokenizer(MemorizingTokenizer):
         return str(out)
 
     def replacer(self, inp: str):
+        """
+
+        :param inp:
+        :return:
+
+        """
+        for excluder in self.normalizers:
+            if not excluder.can_be_replaced and excluder.exclude_regexp.match(inp):
+                return inp
         if self.re_roman_number.match(inp):
             return self.roman_to_number(inp)
         elif inp.isnumeric():
-            if int(inp) > 3:
-                return "3"
-            return str(inp)
+            if inp.isdigit():  # avoid. ↀ
+                if int(inp) > 3:
+                    return "3"
+                else:
+                    return inp
+            return "3"
         elif "." == inp:
             return "."
-        inp = inp.replace("V", "U").replace("v", "u").replace("J", "I").replace("j", "i").replace(".", "").lower()
+
+        if self.re_words.match(inp):  # Might check somehow else but for now... It's weird unidecode normalize into SS
+            inp = unidecode(inp)
+        inp = inp.replace("V", "U").replace("v", "u").replace("J", "I").replace("j", "i").replace(".", "")#.lower()
         return inp
